pub struct Swapchain { /* private fields */ }Expand description
The Vulkan swapchain and associated resources.
Implementations
Sourceimpl Swapchain
impl Swapchain
Sourcepub fn new(
cxt: Arc<VulkanContext>,
framebuffer_size: (u32, u32),
previous_swapchain: Option<SwapchainKHR>,
) -> Result<Self>
pub fn new( cxt: Arc<VulkanContext>, framebuffer_size: (u32, u32), previous_swapchain: Option<SwapchainKHR>, ) -> Result<Self>
Creates a new Vulkan swapchain.
Sourcepub fn raw(&self) -> SwapchainKHR
pub fn raw(&self) -> SwapchainKHR
Returns the non-owning Vulkan swapchain handle.
pub fn viewport(&self) -> Viewport
Sourcepub fn image_views(&self) -> &[ImageView]
pub fn image_views(&self) -> &[ImageView]
Returns the Swapchain’s image views.
Views are paired 1-1 with images of the same index.
Sourcepub fn acquire_image(
&self,
image_ready_semaphore: Semaphore,
) -> Result<AcquireImageStatus>
pub fn acquire_image( &self, image_ready_semaphore: Semaphore, ) -> Result<AcquireImageStatus>
Acquires the index for the next swapchain image.
image_ready_semaphore- A Vulkan semaphore to signal when the swapchain image is ready. This can bevk::Semaphore::null()if not required.
Sourcepub fn present_image(
&self,
wait_semaphore: Semaphore,
image_index: u32,
) -> Result<PresentImageStatus>
pub fn present_image( &self, wait_semaphore: Semaphore, image_index: u32, ) -> Result<PresentImageStatus>
Presents the swapchain image.
wait_semaphore- Image presentation waits for the semaphore to be signalled.image_index- The index of the swapchain image being presented. This must come from a prior call to Self::acquire_image.