pub struct UniformBuffer<DataT: Sized + Copy> { /* private fields */ }Expand description
A CPU accessible buffer with some convenience functions for uploading per-frame data.
Implementations
Sourceimpl<DataT> UniformBuffer<DataT>
impl<DataT> UniformBuffer<DataT>
Sourcepub fn allocate(cxt: &VulkanContext, count: usize) -> Result<Self>
pub fn allocate(cxt: &VulkanContext, count: usize) -> Result<Self>
Allocates a buffer with enough space for count copies of DataT aligned
such that each copy can be bound to a separate descriptor set.
Sourcepub fn allocate_per_frame(
cxt: &VulkanContext,
frames_in_flight: &FramesInFlight,
) -> Result<Self>
pub fn allocate_per_frame( cxt: &VulkanContext, frames_in_flight: &FramesInFlight, ) -> Result<Self>
Allocates a new buffer and GPU memory for holding per-frame uniform data.
Sourcepub fn update_frame_data(&mut self, frame: &Frame, data: DataT) -> Result<()>
pub fn update_frame_data(&mut self, frame: &Frame, data: DataT) -> Result<()>
Updates GPU memory with the provided data for the current frame.
Sourcepub fn offset_for_index(&self, frame_index: usize) -> u64
pub fn offset_for_index(&self, frame_index: usize) -> u64
Returns the byte-offset into the buffer for the corresponding Frame’s data.